# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.pydantic_utilities import pydantic_v1
from ...core.request_options import RequestOptions
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.research_agent_response import ResearchAgentResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ResearchClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def invoke(
        self,
        *,
        config: typing.Dict[str, typing.Any],
        messages: typing.Sequence[typing.Dict[str, typing.Any]],
        request_options: typing.Optional[RequestOptions] = None
    ) -> ResearchAgentResponse:
        """
        Coming soon! Conduct research using web and other sources.

        Parameters
        ----------
        config : typing.Dict[str, typing.Any]
            Configuration for the research agent including search parameters and sources

        messages : typing.Sequence[typing.Dict[str, typing.Any]]
            The messages to send to the research agent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResearchAgentResponse
            Successful Response

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.agents.research.invoke(
            config={"key": "value"},
            messages=[{"key": "value"}],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/agents/research/invoke",
            method="POST",
            json={"config": config, "messages": messages},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ResearchAgentResponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncResearchClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def invoke(
        self,
        *,
        config: typing.Dict[str, typing.Any],
        messages: typing.Sequence[typing.Dict[str, typing.Any]],
        request_options: typing.Optional[RequestOptions] = None
    ) -> ResearchAgentResponse:
        """
        Coming soon! Conduct research using web and other sources.

        Parameters
        ----------
        config : typing.Dict[str, typing.Any]
            Configuration for the research agent including search parameters and sources

        messages : typing.Sequence[typing.Dict[str, typing.Any]]
            The messages to send to the research agent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResearchAgentResponse
            Successful Response

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.agents.research.invoke(
            config={"key": "value"},
            messages=[{"key": "value"}],
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/agents/research/invoke",
            method="POST",
            json={"config": config, "messages": messages},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ResearchAgentResponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Tool(str, enum.Enum):
    SEARCH = "search"
    BROWSE = "browse"

    def visit(self, search: typing.Callable[[], T_Result], browse: typing.Callable[[], T_Result]) -> T_Result:
        if self is Tool.SEARCH:
            return search()
        if self is Tool.BROWSE:
            return browse()



# This file was auto-generated by Fern from our API Definition.

from .types import ToolsDataFrameRequestColumnsItem
from . import calendar, email, structured_data_extractor, tasks

__all__ = ["ToolsDataFrameRequestColumnsItem", "calendar", "email", "structured_data_extractor", "tasks"]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.pydantic_utilities import pydantic_v1
from ...core.request_options import RequestOptions
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.structured_data_extractor_reponse import StructuredDataExtractorReponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class StructuredDataExtractorClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def invoke(
        self,
        *,
        asset_ids: typing.Sequence[str],
        json_schema: typing.Dict[str, typing.Any],
        map_: typing.Optional[bool] = OMIT,
        reduce: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None
    ) -> StructuredDataExtractorReponse:
        """
        Coming soon! Extract structured data from assets of arbitrary length.

        Parameters
        ----------
        asset_ids : typing.Sequence[str]
            The IDs of the assets from which to extract structured data matching `json_schema`.

        json_schema : typing.Dict[str, typing.Any]
            The JSON schema to use for validation (version draft 2020-12).  See the docs [here](https://json-schema.org/learn/getting-started-step-by-step).

        map_ : typing.Optional[bool]
            Whether to split the asset into chunks and attempt to extract the schema from each chunk.  Set to false if you know the asset is small.

        reduce : typing.Optional[bool]
            If `map`, whether to reduce the chunks to a single structured object (true) or return the full list (false).  Use True unless you want to preserve duplicates from each page or expect the object to overflow the output context.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StructuredDataExtractorReponse
            Successful Response

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.structured_data_extractor.invoke(
            asset_ids=["asset_ids"],
            json_schema={"key": "value"},
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/tools/structured-data-extractor/invoke",
            method="POST",
            json={"asset_ids": asset_ids, "json_schema": json_schema, "map": map_, "reduce": reduce},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(StructuredDataExtractorReponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncStructuredDataExtractorClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def invoke(
        self,
        *,
        asset_ids: typing.Sequence[str],
        json_schema: typing.Dict[str, typing.Any],
        map_: typing.Optional[bool] = OMIT,
        reduce: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None
    ) -> StructuredDataExtractorReponse:
        """
        Coming soon! Extract structured data from assets of arbitrary length.

        Parameters
        ----------
        asset_ids : typing.Sequence[str]
            The IDs of the assets from which to extract structured data matching `json_schema`.

        json_schema : typing.Dict[str, typing.Any]
            The JSON schema to use for validation (version draft 2020-12).  See the docs [here](https://json-schema.org/learn/getting-started-step-by-step).

        map_ : typing.Optional[bool]
            Whether to split the asset into chunks and attempt to extract the schema from each chunk.  Set to false if you know the asset is small.

        reduce : typing.Optional[bool]
            If `map`, whether to reduce the chunks to a single structured object (true) or return the full list (false).  Use True unless you want to preserve duplicates from each page or expect the object to overflow the output context.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StructuredDataExtractorReponse
            Successful Response

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.tools.structured_data_extractor.invoke(
            asset_ids=["asset_ids"],
            json_schema={"key": "value"},
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/tools/structured-data-extractor/invoke",
            method="POST",
            json={"asset_ids": asset_ids, "json_schema": json_schema, "map": map_, "reduce": reduce},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(StructuredDataExtractorReponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from .types import (
    AssetNotFoundError,
    CustomAgentResponse,
    DataFrameRequestOut,
    DataFrameRequestOutColumnsItem,
    DataFrameRequestOutDataItemItem,
    DataFrameRequestOutIndexItem,
    DataFrameUnknownFormatError,
    DocumentChunk,
    DriveAgentResponse,
    FileChunkRequestOut,
    FileTooLargeError,
    GeneralAgentConfig,
    GeneralAgentConfigEnabledToolsItem,
    GeneralAgentRequest,
    GeneralAgentResponse,
    ParentFolderError,
    ResearchAgentResponse,
    SaveAssetRequestOut,
    SqlAgentResponse,
    StructuredDataExtractorReponse,
    Tool,
)
from .errors import (
    BadRequestError,
    ContentTooLargeError,
    InternalServerError,
    NotFoundError,
    UnauthorizedError,
    UnprocessableEntityError,
    UnsupportedMediaTypeError,
)
from . import agents, query, tools
from .environment import AthenaEnvironment
from .query import QueryExecuteRequestDatabaseAssetIds
from .tools import ToolsDataFrameRequestColumnsItem
from .version import __version__

__all__ = [
    "AssetNotFoundError",
    "AthenaEnvironment",
    "BadRequestError",
    "ContentTooLargeError",
    "CustomAgentResponse",
    "DataFrameRequestOut",
    "DataFrameRequestOutColumnsItem",
    "DataFrameRequestOutDataItemItem",
    "DataFrameRequestOutIndexItem",
    "DataFrameUnknownFormatError",
    "DocumentChunk",
    "DriveAgentResponse",
    "FileChunkRequestOut",
    "FileTooLargeError",
    "GeneralAgentConfig",
    "GeneralAgentConfigEnabledToolsItem",
    "GeneralAgentRequest",
    "GeneralAgentResponse",
    "InternalServerError",
    "NotFoundError",
    "ParentFolderError",
    "QueryExecuteRequestDatabaseAssetIds",
    "ResearchAgentResponse",
    "SaveAssetRequestOut",
    "SqlAgentResponse",
    "StructuredDataExtractorReponse",
    "Tool",
    "ToolsDataFrameRequestColumnsItem",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "UnsupportedMediaTypeError",
    "__version__",
    "agents",
    "query",
    "tools",
]



# This file was auto-generated by Fern from our API Definition.

from .asset_not_found_error import AssetNotFoundError
from .custom_agent_response import CustomAgentResponse
from .data_frame_request_out import DataFrameRequestOut
from .data_frame_request_out_columns_item import DataFrameRequestOutColumnsItem
from .data_frame_request_out_data_item_item import DataFrameRequestOutDataItemItem
from .data_frame_request_out_index_item import DataFrameRequestOutIndexItem
from .data_frame_unknown_format_error import DataFrameUnknownFormatError
from .document_chunk import DocumentChunk
from .drive_agent_response import DriveAgentResponse
from .file_chunk_request_out import FileChunkRequestOut
from .file_too_large_error import FileTooLargeError
from .general_agent_config import GeneralAgentConfig
from .general_agent_config_enabled_tools_item import GeneralAgentConfigEnabledToolsItem
from .general_agent_request import GeneralAgentRequest
from .general_agent_response import GeneralAgentResponse
from .parent_folder_error import ParentFolderError
from .research_agent_response import ResearchAgentResponse
from .save_asset_request_out import SaveAssetRequestOut
from .sql_agent_response import SqlAgentResponse
from .structured_data_extractor_reponse import StructuredDataExtractorReponse
from .tool import Tool

__all__ = [
    "AssetNotFoundError",
    "CustomAgentResponse",
    "DataFrameRequestOut",
    "DataFrameRequestOutColumnsItem",
    "DataFrameRequestOutDataItemItem",
    "DataFrameRequestOutIndexItem",
    "DataFrameUnknownFormatError",
    "DocumentChunk",
    "DriveAgentResponse",
    "FileChunkRequestOut",
    "FileTooLargeError",
    "GeneralAgentConfig",
    "GeneralAgentConfigEnabledToolsItem",
    "GeneralAgentRequest",
    "GeneralAgentResponse",
    "ParentFolderError",
    "ResearchAgentResponse",
    "SaveAssetRequestOut",
    "SqlAgentResponse",
    "StructuredDataExtractorReponse",
    "Tool",
]



# This file was auto-generated by Fern from our API Definition.

from .query_execute_request_database_asset_ids import QueryExecuteRequestDatabaseAssetIds

__all__ = ["QueryExecuteRequestDatabaseAssetIds"]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import pydantic_v1
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.custom_agent_response import CustomAgentResponse
from .drive.client import AsyncDriveClient, DriveClient
from .general.client import AsyncGeneralClient, GeneralClient
from .research.client import AsyncResearchClient, ResearchClient
from .sql.client import AsyncSqlClient, SqlClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class AgentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.drive = DriveClient(client_wrapper=self._client_wrapper)
        self.general = GeneralClient(client_wrapper=self._client_wrapper)
        self.research = ResearchClient(client_wrapper=self._client_wrapper)
        self.sql = SqlClient(client_wrapper=self._client_wrapper)

    def invoke_by_id(
        self,
        agent_id: str,
        *,
        config: typing.Dict[str, typing.Any],
        messages: typing.Sequence[typing.Dict[str, typing.Any]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CustomAgentResponse:
        """
        Coming soon!

        Invoke a custom agent created in [spaces](https://resources.athenaintel.com/docs/agents/create-your-agent).

        Custom agents can be created and configured in spaces to perform specialized tasks.
        Refer to the specific agent's documentation for details on configuration options
        and expected responses.

        Parameters
        ----------
        agent_id : str
            The ID of the custom agent to invoke. Create custom agents in [spaces](https://resources.athenaintel.com/docs/agents/create-your-agent).

        config : typing.Dict[str, typing.Any]
            Configuration for the custom agent. See the agent's documentation for specific configuration options.

        messages : typing.Sequence[typing.Dict[str, typing.Any]]
            The messages to send to the custom agent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CustomAgentResponse
            Successful Response

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.agents.invoke_by_id(
            agent_id="agent_id",
            config={"key": "value"},
            messages=[{"key": "value"}],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/v0/agents/{jsonable_encoder(agent_id)}/invoke",
            method="POST",
            json={"config": config, "messages": messages},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(CustomAgentResponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncAgentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.drive = AsyncDriveClient(client_wrapper=self._client_wrapper)
        self.general = AsyncGeneralClient(client_wrapper=self._client_wrapper)
        self.research = AsyncResearchClient(client_wrapper=self._client_wrapper)
        self.sql = AsyncSqlClient(client_wrapper=self._client_wrapper)

    async def invoke_by_id(
        self,
        agent_id: str,
        *,
        config: typing.Dict[str, typing.Any],
        messages: typing.Sequence[typing.Dict[str, typing.Any]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CustomAgentResponse:
        """
        Coming soon!

        Invoke a custom agent created in [spaces](https://resources.athenaintel.com/docs/agents/create-your-agent).

        Custom agents can be created and configured in spaces to perform specialized tasks.
        Refer to the specific agent's documentation for details on configuration options
        and expected responses.

        Parameters
        ----------
        agent_id : str
            The ID of the custom agent to invoke. Create custom agents in [spaces](https://resources.athenaintel.com/docs/agents/create-your-agent).

        config : typing.Dict[str, typing.Any]
            Configuration for the custom agent. See the agent's documentation for specific configuration options.

        messages : typing.Sequence[typing.Dict[str, typing.Any]]
            The messages to send to the custom agent

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CustomAgentResponse
            Successful Response

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.agents.invoke_by_id(
            agent_id="agent_id",
            config={"key": "value"},
            messages=[{"key": "value"}],
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/v0/agents/{jsonable_encoder(agent_id)}/invoke",
            method="POST",
            json={"config": config, "messages": messages},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(CustomAgentResponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.pydantic_utilities import pydantic_v1
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..errors.content_too_large_error import ContentTooLargeError
from ..errors.internal_server_error import InternalServerError
from ..errors.not_found_error import NotFoundError
from ..errors.unauthorized_error import UnauthorizedError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..errors.unsupported_media_type_error import UnsupportedMediaTypeError
from ..types.asset_not_found_error import AssetNotFoundError
from ..types.data_frame_request_out import DataFrameRequestOut
from ..types.data_frame_unknown_format_error import DataFrameUnknownFormatError
from ..types.file_chunk_request_out import FileChunkRequestOut
from ..types.file_too_large_error import FileTooLargeError
from ..types.parent_folder_error import ParentFolderError
from ..types.save_asset_request_out import SaveAssetRequestOut
from .calendar.client import AsyncCalendarClient, CalendarClient
from .email.client import AsyncEmailClient, EmailClient
from .structured_data_extractor.client import AsyncStructuredDataExtractorClient, StructuredDataExtractorClient
from .tasks.client import AsyncTasksClient, TasksClient
from .types.tools_data_frame_request_columns_item import ToolsDataFrameRequestColumnsItem

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ToolsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.calendar = CalendarClient(client_wrapper=self._client_wrapper)
        self.email = EmailClient(client_wrapper=self._client_wrapper)
        self.structured_data_extractor = StructuredDataExtractorClient(client_wrapper=self._client_wrapper)
        self.tasks = TasksClient(client_wrapper=self._client_wrapper)

    def get_asset_chunks(
        self, *, asset_ids: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> FileChunkRequestOut:
        """
        Get the chunks of a file.

        Parameters
        ----------
        asset_ids : typing.Sequence[str]
            Identifiers of the assets

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileChunkRequestOut
            Successful Response

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.get_asset_chunks(
            asset_ids=[
                "asset_9249292-d118-42d3-96b4-00eccfe0754f",
                "asset_9249292-d118-42d3-95b4-01eccfe0754f",
            ],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/tools/asset/chunks",
            method="POST",
            json={"asset_ids": asset_ids},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(FileChunkRequestOut, _response.json())  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic_v1.parse_obj_as(AssetNotFoundError, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def data_frame(
        self,
        *,
        asset_id: str,
        row_limit: typing.Optional[int] = None,
        index_column: typing.Optional[int] = None,
        columns: typing.Optional[
            typing.Union[ToolsDataFrameRequestColumnsItem, typing.Sequence[ToolsDataFrameRequestColumnsItem]]
        ] = None,
        sheet_name: typing.Optional[int] = None,
        separator: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None
    ) -> DataFrameRequestOut:
        """
        Parameters
        ----------
        asset_id : str

        row_limit : typing.Optional[int]

        index_column : typing.Optional[int]

        columns : typing.Optional[typing.Union[ToolsDataFrameRequestColumnsItem, typing.Sequence[ToolsDataFrameRequestColumnsItem]]]
            should be a list of strings or a list of integers

        sheet_name : typing.Optional[int]
            only for excel files

        separator : typing.Optional[str]
            only for csv files

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DataFrameRequestOut
            Successful Response

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.data_frame(
            asset_id="asset_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/tools/file/data-frame",
            method="GET",
            params={
                "asset_id": asset_id,
                "row_limit": row_limit,
                "index_column": index_column,
                "columns": columns,
                "sheet_name": sheet_name,
                "separator": separator,
            },
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(DataFrameRequestOut, _response.json())  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic_v1.parse_obj_as(AssetNotFoundError, _response.json()))  # type: ignore
        if _response.status_code == 415:
            raise UnsupportedMediaTypeError(
                pydantic_v1.parse_obj_as(DataFrameUnknownFormatError, _response.json())  # type: ignore
            )
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 500:
            raise InternalServerError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def raw_data(
        self, *, asset_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Iterator[bytes]:
        """
        Get the raw file data for given asset.

        Parameters
        ----------
        asset_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.Iterator[bytes]
            Stream the file in original format.

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.raw_data(
            asset_id="string",
        )
        """
        with self._client_wrapper.httpx_client.stream(
            "api/v0/tools/file/raw-data", method="GET", params={"asset_id": asset_id}, request_options=request_options
        ) as _response:
            if 200 <= _response.status_code < 300:
                for _chunk in _response.iter_bytes():
                    yield _chunk
                return
            _response.read()
            if _response.status_code == 401:
                raise UnauthorizedError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
            if _response.status_code == 404:
                raise NotFoundError(pydantic_v1.parse_obj_as(AssetNotFoundError, _response.json()))  # type: ignore
            if _response.status_code == 422:
                raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
            if _response.status_code == 500:
                raise InternalServerError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
            try:
                _response_json = _response.json()
            except JSONDecodeError:
                raise ApiError(status_code=_response.status_code, body=_response.text)
            raise ApiError(status_code=_response.status_code, body=_response_json)

    def save_asset(
        self,
        *,
        file: core.File,
        parent_folder_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None
    ) -> SaveAssetRequestOut:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        parent_folder_id : typing.Optional[str]
            Identifier of the folder into which the asset should be saved

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SaveAssetRequestOut
            Successful Response

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.save_asset()
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/tools/file/save",
            method="POST",
            params={"parent_folder_id": parent_folder_id},
            data={},
            files={"file": file},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(SaveAssetRequestOut, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic_v1.parse_obj_as(ParentFolderError, _response.json()))  # type: ignore
        if _response.status_code == 413:
            raise ContentTooLargeError(pydantic_v1.parse_obj_as(FileTooLargeError, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncToolsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.calendar = AsyncCalendarClient(client_wrapper=self._client_wrapper)
        self.email = AsyncEmailClient(client_wrapper=self._client_wrapper)
        self.structured_data_extractor = AsyncStructuredDataExtractorClient(client_wrapper=self._client_wrapper)
        self.tasks = AsyncTasksClient(client_wrapper=self._client_wrapper)

    async def get_asset_chunks(
        self, *, asset_ids: typing.Sequence[str], request_options: typing.Optional[RequestOptions] = None
    ) -> FileChunkRequestOut:
        """
        Get the chunks of a file.

        Parameters
        ----------
        asset_ids : typing.Sequence[str]
            Identifiers of the assets

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileChunkRequestOut
            Successful Response

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.tools.get_asset_chunks(
            asset_ids=[
                "asset_9249292-d118-42d3-96b4-00eccfe0754f",
                "asset_9249292-d118-42d3-95b4-01eccfe0754f",
            ],
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/tools/asset/chunks",
            method="POST",
            json={"asset_ids": asset_ids},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(FileChunkRequestOut, _response.json())  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic_v1.parse_obj_as(AssetNotFoundError, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def data_frame(
        self,
        *,
        asset_id: str,
        row_limit: typing.Optional[int] = None,
        index_column: typing.Optional[int] = None,
        columns: typing.Optional[
            typing.Union[ToolsDataFrameRequestColumnsItem, typing.Sequence[ToolsDataFrameRequestColumnsItem]]
        ] = None,
        sheet_name: typing.Optional[int] = None,
        separator: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None
    ) -> DataFrameRequestOut:
        """
        Parameters
        ----------
        asset_id : str

        row_limit : typing.Optional[int]

        index_column : typing.Optional[int]

        columns : typing.Optional[typing.Union[ToolsDataFrameRequestColumnsItem, typing.Sequence[ToolsDataFrameRequestColumnsItem]]]
            should be a list of strings or a list of integers

        sheet_name : typing.Optional[int]
            only for excel files

        separator : typing.Optional[str]
            only for csv files

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DataFrameRequestOut
            Successful Response

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.tools.data_frame(
            asset_id="asset_id",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/tools/file/data-frame",
            method="GET",
            params={
                "asset_id": asset_id,
                "row_limit": row_limit,
                "index_column": index_column,
                "columns": columns,
                "sheet_name": sheet_name,
                "separator": separator,
            },
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(DataFrameRequestOut, _response.json())  # type: ignore
        if _response.status_code == 401:
            raise UnauthorizedError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic_v1.parse_obj_as(AssetNotFoundError, _response.json()))  # type: ignore
        if _response.status_code == 415:
            raise UnsupportedMediaTypeError(
                pydantic_v1.parse_obj_as(DataFrameUnknownFormatError, _response.json())  # type: ignore
            )
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 500:
            raise InternalServerError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def raw_data(
        self, *, asset_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.AsyncIterator[bytes]:
        """
        Get the raw file data for given asset.

        Parameters
        ----------
        asset_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.AsyncIterator[bytes]
            Stream the file in original format.

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.tools.raw_data(
            asset_id="string",
        )
        """
        async with self._client_wrapper.httpx_client.stream(
            "api/v0/tools/file/raw-data", method="GET", params={"asset_id": asset_id}, request_options=request_options
        ) as _response:
            if 200 <= _response.status_code < 300:
                async for _chunk in _response.aiter_bytes():
                    yield _chunk
                return
            await _response.aread()
            if _response.status_code == 401:
                raise UnauthorizedError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
            if _response.status_code == 404:
                raise NotFoundError(pydantic_v1.parse_obj_as(AssetNotFoundError, _response.json()))  # type: ignore
            if _response.status_code == 422:
                raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
            if _response.status_code == 500:
                raise InternalServerError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
            try:
                _response_json = _response.json()
            except JSONDecodeError:
                raise ApiError(status_code=_response.status_code, body=_response.text)
            raise ApiError(status_code=_response.status_code, body=_response_json)

    async def save_asset(
        self,
        *,
        file: core.File,
        parent_folder_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None
    ) -> SaveAssetRequestOut:
        """
        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        parent_folder_id : typing.Optional[str]
            Identifier of the folder into which the asset should be saved

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SaveAssetRequestOut
            Successful Response

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.tools.save_asset()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/tools/file/save",
            method="POST",
            params={"parent_folder_id": parent_folder_id},
            data={},
            files={"file": file},
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(SaveAssetRequestOut, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic_v1.parse_obj_as(ParentFolderError, _response.json()))  # type: ignore
        if _response.status_code == 413:
            raise ContentTooLargeError(pydantic_v1.parse_obj_as(FileTooLargeError, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from .bad_request_error import BadRequestError
from .content_too_large_error import ContentTooLargeError
from .internal_server_error import InternalServerError
from .not_found_error import NotFoundError
from .unauthorized_error import UnauthorizedError
from .unprocessable_entity_error import UnprocessableEntityError
from .unsupported_media_type_error import UnsupportedMediaTypeError

__all__ = [
    "BadRequestError",
    "ContentTooLargeError",
    "InternalServerError",
    "NotFoundError",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "UnsupportedMediaTypeError",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.pydantic_utilities import pydantic_v1
from ...core.request_options import RequestOptions
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.general_agent_request import GeneralAgentRequest
from ...types.general_agent_response import GeneralAgentResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class GeneralClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def batch(
        self, *, request: typing.Sequence[GeneralAgentRequest], request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[GeneralAgentResponse]:
        """
        Coming soon! Call the general agent with batched requests and return the results.

        Parameters
        ----------
        request : typing.Sequence[GeneralAgentRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[GeneralAgentResponse]
            Successful Response

        Examples
        --------
        from athena import GeneralAgentConfig, GeneralAgentRequest, Tool
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.agents.general.batch(
            request=[
                GeneralAgentRequest(
                    config=GeneralAgentConfig(
                        enabled_tools=[Tool.SEARCH],
                    ),
                    messages=[
                        {
                            "content": "Please call the search tool for AAPL news.",
                            "type": "user",
                        }
                    ],
                )
            ],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/agents/general/batch", method="POST", json=request, request_options=request_options, omit=OMIT
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.List[GeneralAgentResponse], _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def invoke(
        self, *, request: GeneralAgentRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralAgentResponse:
        """
        Call the general Athena agent synchronously.

        Call the agent with the messages list, wait for the agent to complete,
        and return the result.

        Parameters
        ----------
        request : GeneralAgentRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralAgentResponse
            Successful Response

        Examples
        --------
        from athena import GeneralAgentConfig, GeneralAgentRequest, Tool
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.agents.general.invoke(
            request=GeneralAgentRequest(
                config=GeneralAgentConfig(
                    enabled_tools=[Tool.SEARCH],
                ),
                messages=[
                    {
                        "content": "Please call the search tool for AAPL news.",
                        "type": "user",
                    }
                ],
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/agents/general/invoke", method="POST", json=request, request_options=request_options, omit=OMIT
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(GeneralAgentResponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def stream_events(
        self, *, request: GeneralAgentRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralAgentResponse:
        """
        Coming soon! Call the general agent and stream events for real-time chat applications.

        Parameters
        ----------
        request : GeneralAgentRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralAgentResponse
            Successful Response

        Examples
        --------
        from athena import GeneralAgentConfig, GeneralAgentRequest, Tool
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.agents.general.stream_events(
            request=GeneralAgentRequest(
                config=GeneralAgentConfig(
                    enabled_tools=[Tool.SEARCH],
                ),
                messages=[
                    {
                        "content": "Please call the search tool for AAPL news.",
                        "type": "user",
                    }
                ],
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/agents/general/stream_events",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(GeneralAgentResponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncGeneralClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def batch(
        self, *, request: typing.Sequence[GeneralAgentRequest], request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[GeneralAgentResponse]:
        """
        Coming soon! Call the general agent with batched requests and return the results.

        Parameters
        ----------
        request : typing.Sequence[GeneralAgentRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[GeneralAgentResponse]
            Successful Response

        Examples
        --------
        from athena import GeneralAgentConfig, GeneralAgentRequest, Tool
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.agents.general.batch(
            request=[
                GeneralAgentRequest(
                    config=GeneralAgentConfig(
                        enabled_tools=[Tool.SEARCH],
                    ),
                    messages=[
                        {
                            "content": "Please call the search tool for AAPL news.",
                            "type": "user",
                        }
                    ],
                )
            ],
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/agents/general/batch", method="POST", json=request, request_options=request_options, omit=OMIT
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.List[GeneralAgentResponse], _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def invoke(
        self, *, request: GeneralAgentRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralAgentResponse:
        """
        Call the general Athena agent synchronously.

        Call the agent with the messages list, wait for the agent to complete,
        and return the result.

        Parameters
        ----------
        request : GeneralAgentRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralAgentResponse
            Successful Response

        Examples
        --------
        from athena import GeneralAgentConfig, GeneralAgentRequest, Tool
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.agents.general.invoke(
            request=GeneralAgentRequest(
                config=GeneralAgentConfig(
                    enabled_tools=[Tool.SEARCH],
                ),
                messages=[
                    {
                        "content": "Please call the search tool for AAPL news.",
                        "type": "user",
                    }
                ],
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/agents/general/invoke", method="POST", json=request, request_options=request_options, omit=OMIT
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(GeneralAgentResponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def stream_events(
        self, *, request: GeneralAgentRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralAgentResponse:
        """
        Coming soon! Call the general agent and stream events for real-time chat applications.

        Parameters
        ----------
        request : GeneralAgentRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralAgentResponse
            Successful Response

        Examples
        --------
        from athena import GeneralAgentConfig, GeneralAgentRequest, Tool
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.agents.general.stream_events(
            request=GeneralAgentRequest(
                config=GeneralAgentConfig(
                    enabled_tools=[Tool.SEARCH],
                ),
                messages=[
                    {
                        "content": "Please call the search tool for AAPL news.",
                        "type": "user",
                    }
                ],
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/agents/general/stream_events",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(GeneralAgentResponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.pydantic_utilities import pydantic_v1
from ...core.request_options import RequestOptions


class CalendarClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list_events(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Coming soon! List calendar events with optional filtering.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.calendar.list_events()
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/tools/calendar/events", method="GET", request_options=request_options
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.Any, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_event(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Coming soon! Create new calendar events.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.calendar.create_event()
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/tools/calendar/events", method="POST", request_options=request_options
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.Any, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncCalendarClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list_events(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Coming soon! List calendar events with optional filtering.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.tools.calendar.list_events()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/tools/calendar/events", method="GET", request_options=request_options
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.Any, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_event(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Any:
        """
        Coming soon! Create new calendar events.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any
            Successful Response

        Examples
        --------
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.tools.calendar.create_event()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/tools/calendar/events", method="POST", request_options=request_options
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.Any, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)
